matminer.data_retrieval.tests package — matminer 0.9.1 documentation

# matminer.data_retrieval.tests package

## Submodules

## matminer.data_retrieval.tests.base module

## matminer.data_retrieval.tests.test_retrieve_AFLOW module

class matminer.data_retrieval.tests.test_retrieve_AFLOW.AFLOWDataRetrievalTest(methodName='runTest')

  Bases: `TestCase`

  setUp()

    Hook method for setting up the test fixture before exercising it.

  test_get_data()

## matminer.data_retrieval.tests.test_retrieve_Citrine module

class matminer.data_retrieval.tests.test_retrieve_Citrine.CitrineDataRetrievalTest(methodName='runTest')

  Bases: `TestCase`

  setUp()

    Hook method for setting up the test fixture before exercising it.

  test_get_data()
  test_multiple_items_in_list()

## matminer.data_retrieval.tests.test_retrieve_MDF module

class matminer.data_retrieval.tests.test_retrieve_MDF.MDFDataRetrievalTest(methodName='runTest')

  Bases: `TestCase`

  classmethod setUpClass() → None

    Hook method for setting up class fixture before running tests in the class.

  test_get_dataframe()
  test_get_dataframe_by_query()
  test_make_dataframe()

## matminer.data_retrieval.tests.test_retrieve_MP module

class matminer.data_retrieval.tests.test_retrieve_MP.MPDataRetrievalTest(methodName='runTest')

  Bases: `TestCase`

  setUp()

    Hook method for setting up the test fixture before exercising it.

  test_get_data()

## matminer.data_retrieval.tests.test_retrieve_MPDS module

class matminer.data_retrieval.tests.test_retrieve_MPDS.MPDSDataRetrievalTest(methodName='runTest')

  Bases: `TestCase`

  setUp()

    Hook method for setting up the test fixture before exercising it.

  test_valid_answer()

## matminer.data_retrieval.tests.test_retrieve_MongoDB module

class matminer.data_retrieval.tests.test_retrieve_MongoDB.MongoDataRetrievalTest(methodName='runTest')

  Bases: `PymatgenTest`

  test_cleaned_projection()
  test_get_dataframe()
  test_remove_ints()

## Module contents